run_search

Function run_search 

pub async fn run_search(
    config: &SandboxConfig,
    code: &str,
    manifest: &Value,
) -> Result<Value, SandboxError>
Run a search operation on the current thread (must be called from a dedicated thread, not the main tokio runtime).

Public for reuse in the worker binary.