#[non_exhaustive]pub enum ParentMessage {
Execute {
code: String,
manifest: Option<Value>,
config: WorkerConfig,
},
ToolCallResult {
request_id: u64,
result: Result<Value, IpcDispatchError>,
},
ResourceReadResult {
request_id: u64,
result: Result<Value, IpcDispatchError>,
},
Reset {
config: WorkerConfig,
},
StashResult {
request_id: u64,
result: Result<Value, IpcDispatchError>,
},
}Expand description
Messages sent from the parent process to the worker child.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Execute
Initial message: execute this code in the sandbox.
Fields

manifest: Option<Value>Optional capability manifest (for search mode — not used in child process execute).

config: WorkerConfigWorker configuration.
ToolCallResult
Response to a tool call request from the child.
Fields

result: Result<Value, IpcDispatchError>The tool call result, or a structured dispatch error.
ResourceReadResult
Response to a resource read request from the child.
Fields

result: Result<Value, IpcDispatchError>The resource content, or a structured dispatch error.
Reset
Reset the worker for a new execution (pool mode).
The worker drops its current JsRuntime and creates a fresh one.
It responds with ChildMessage::ResetComplete.
Fields

config: WorkerConfigNew worker configuration for the next execution.
StashResult
Response to a stash operation from the child.